#
# WG21-meeting-att.R, 13 Dec 20
#
# Data extracted from meeting minutes on WG21 website


source("ESEUR_config.r")


library("plyr")
library("survival")


pal_col=rainbow(2)

plot_layout(2, 1,
		default_width=ESEUR_max_width,
		default_height=2*ESEUR_default_height)

par(cex=0.9)
par(cex.axis=1.4)
par(cex.lab=1.4)


# Estimate start/end of interval for each attendee
start_end_int=function(df)
{
first_date=min(df$Date)
first_meet=min(df$Meeting)
last_date=max(df$Date)
last_meet=max(df$Meeting)

died_date=(last_date < cutoff_date)
died_meet=(last_meet < cutoff_meet)

# Base meeting date/number on the first one in the dataset
first_date=first_date-start_date
first_meet=first_meet-start_meet
last_date=last_date-start_date
last_meet=last_meet-start_meet

t=data.frame(first_date, last_date, first_meet, last_meet,
		died_date, died_meet, attendee=df$Representative[1])
return(t)
}


wg=read.csv("attendees.csv", as.is=TRUE)

wg$Date=as.Date(wg$Date, format="%Y-%m-%d")

# sort(unique(wg$Date))
# sort(unique(wg$Meeting))

wg$Meeting=as.numeric(wg$Meeting)

start_date=as.Date("2004-01-01", format="%Y-%m-%d")
start_meet=32
cutoff_date=as.Date("2015-01-01", format="%Y-%m-%d")
cutoff_meet=61
max_date=max(wg$Date, na.rm=TRUE)
max_meet=64

wg=subset(wg, Date > start_date)

# table(subset(wg, nchar(Representative)==2)$Representative)

NBs=c("BG", "CA", "CH", "DE", "ES", "FI", "FR", "JL",
	"NB", "NL", "NO", "NW", "RU", "SI", "UK", "US",
	"Slovenia", "Netherlands (HoD)", "Country") 

nb_ind=(wg$Representative %in% NBs)
wg$Representative[nb_ind]=wg$Mon[nb_ind]

# table(wg$Representative)
# 
# plot(table(table(wg$Representative)), xlim=c(1, 32), ylim=c(1,50))

att_span=ddply(wg, .(Representative), start_end_int)

att_span=subset(att_span, !is.na(died_date))

date_Surv=Surv(time=att_span$first_date, time2=att_span$last_date,
			event=as.numeric(att_span$died_date), type="interval")
date_fit=survfit(date_Surv ~ 1)
plot(date_fit, col=pal_col[c(1, 2, 2)],
	xaxs="i", yaxs="i",
	ylim=c(0, 1),
	xlab="Days since 2004-01-01", ylab="Survival\n")


meet_Surv=Surv(time=att_span$first_meet, time2=att_span$last_meet,
			event=as.numeric(att_span$died_meet), type="interval")
meet_fit=survfit(meet_Surv ~ 1)
plot(meet_fit, col=pal_col[c(1, 2, 2)],
	xaxs="i", yaxs="i",
	ylim=c(0, 1),
	xlab="Meetings", ylab="Survival\n")

